Struct ExportLogsServiceRequest
pub struct ExportLogsServiceRequest {
pub resource_logs: Vec<ResourceLogs>,
}Fields
resource_logs: Vec<ResourceLogs>An array of ResourceLogs. For data coming from a single resource this array will typically contain one element. Intermediary nodes (such as OpenTelemetry Collector) that receive data from multiple origins typically batch the data before forwarding further and in that case this array will contain multiple elements.