Struct ExportMetricsServiceRequest
pub struct ExportMetricsServiceRequest {
pub resource_metrics: Vec<ResourceMetrics>,
}Fields
resource_metrics: Vec<ResourceMetrics>An array of ResourceMetrics. For data coming from a single resource this array will typically contain one element. Intermediary nodes (such as OpenTelemetry Collector) that receive data from multiple origins typically batch the data before forwarding further and in that case this array will contain multiple elements.