Struct ExportTraceServiceRequest
pub struct ExportTraceServiceRequest {
pub resource_spans: Vec<ResourceSpans>,
}Fields
resource_spans: Vec<ResourceSpans>An array of ResourceSpans. For data coming from a single resource this array will typically contain one element. Intermediary nodes (such as OpenTelemetry Collector) that receive data from multiple origins typically batch the data before forwarding further and in that case this array will contain multiple elements.