ExportTraceServiceResponse

Struct ExportTraceServiceResponse 

pub struct ExportTraceServiceResponse {
    pub partial_success: Option<ExportTracePartialSuccess>,
}

Fields

partial_success: Option<ExportTracePartialSuccess>

The details of a partially successful export request.

If the request is only partially accepted (i.e. when the server accepts only parts of the data and rejects the rest) the server MUST initialize the partial_success field and MUST set the rejected_<signal> with the number of items it rejected.

Servers MAY also make use of the partial_success field to convey warnings/suggestions to senders even when the request was fully accepted. In such cases, the rejected_<signal> MUST have a value of 0 and the error_message MUST be non-empty.

A partial_success message with an empty value (rejected_ = 0 and error_message = “”) is equivalent to it not being set/present. Senders SHOULD interpret it the same way as in the full success case.