Struct MetricsServiceClient
pub struct MetricsServiceClient<T> { /* private fields */ }Expand description
Service that can be used to push metrics between one Application instrumented with OpenTelemetry and a collector, or between a collector and a central collector.
Implementations
impl MetricsServiceClient<Channel>
impl MetricsServiceClient<Channel>
impl<T> MetricsServiceClient<T>
impl<T> MetricsServiceClient<T>
pub fn new(inner: T) -> MetricsServiceClient<T>
pub fn with_origin(inner: T, origin: Uri) -> MetricsServiceClient<T>
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> MetricsServiceClient<InterceptedService<T, F>>
pub fn send_compressed(
self,
encoding: CompressionEncoding,
) -> MetricsServiceClient<T>
pub fn send_compressed( self, encoding: CompressionEncoding, ) -> MetricsServiceClient<T>
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
pub fn accept_compressed(
self,
encoding: CompressionEncoding,
) -> MetricsServiceClient<T>
pub fn accept_compressed( self, encoding: CompressionEncoding, ) -> MetricsServiceClient<T>
Enable decompressing responses.
pub fn max_decoding_message_size(self, limit: usize) -> MetricsServiceClient<T>
pub fn max_decoding_message_size(self, limit: usize) -> MetricsServiceClient<T>
Limits the maximum size of a decoded message.
Default: 4MB
pub fn max_encoding_message_size(self, limit: usize) -> MetricsServiceClient<T>
pub fn max_encoding_message_size(self, limit: usize) -> MetricsServiceClient<T>
Limits the maximum size of an encoded message.
Default: usize::MAX
pub async fn export( &mut self, request: impl IntoRequest<ExportMetricsServiceRequest>, ) -> Result<Response<ExportMetricsServiceResponse>, Status>