Struct ResourceLogs
pub struct ResourceLogs {
pub resource: Option<Resource>,
pub scope_logs: Vec<ScopeLogs>,
pub schema_url: String,
}Expand description
A collection of ScopeLogs from a Resource.
Fields
resource: Option<Resource>The resource for the logs in this message. If this field is not set then resource info is unknown.
scope_logs: Vec<ScopeLogs>A list of ScopeLogs that originate from a resource.
schema_url: StringThe Schema URL, if known. This is the identifier of the Schema that the resource data
is recorded in. Notably, the last part of the URL path is the version number of the
schema: http[s]://server[:port]/path/