Struct ResourceMetrics
pub struct ResourceMetrics {
pub resource: Option<Resource>,
pub scope_metrics: Vec<ScopeMetrics>,
pub schema_url: String,
}Expand description
A collection of ScopeMetrics from a Resource.
Fields
resource: Option<Resource>The resource for the metrics in this message. If this field is not set then no resource info is known.
scope_metrics: Vec<ScopeMetrics>A list of metrics that originate from a resource.
schema_url: StringThe Schema URL, if known. This is the identifier of the Schema that the resource data
is recorded in. Notably, the last part of the URL path is the version number of the
schema: http[s]://server[:port]/path/