Struct ScopeLogs
pub struct ScopeLogs {
pub scope: Option<InstrumentationScope>,
pub log_records: Vec<LogRecord>,
pub schema_url: String,
}Expand description
A collection of Logs produced by a Scope.
Fields
scope: Option<InstrumentationScope>The instrumentation scope information for the logs in this message. Semantically when InstrumentationScope isn’t set, it is equivalent with an empty instrumentation scope name (unknown).
log_records: Vec<LogRecord>A list of log records.
schema_url: StringThe Schema URL, if known. This is the identifier of the Schema that the log data
is recorded in. Notably, the last part of the URL path is the version number of the
schema: http[s]://server[:port]/path/