Struct ScopeMetrics
pub struct ScopeMetrics {
pub scope: Option<InstrumentationScope>,
pub metrics: Vec<Metric>,
pub schema_url: String,
}Expand description
A collection of Metrics produced by an Scope.
Fields
scope: Option<InstrumentationScope>The instrumentation scope information for the metrics in this message. Semantically when InstrumentationScope isn’t set, it is equivalent with an empty instrumentation scope name (unknown).
metrics: Vec<Metric>A list of metrics that originate from an instrumentation library.
schema_url: StringThe Schema URL, if known. This is the identifier of the Schema that the metric data
is recorded in. Notably, the last part of the URL path is the version number of the
schema: http[s]://server[:port]/path/